@@ -93,6 +93,7 @@ destroy_user_data (gpointer p)
   g_free (p);
 }
 
+
 static void
 recalculate_sensitivities (GtkWidget *widget,
                            GtkWidget *d)
@@ -182,6 +183,26 @@ recalculate_sensitivities (GtkWidget *widget,
     }
 }
 
+
+static void
+weekly_toggled (GtkWidget *widget,
+                           GtkWidget *d)
+{
+  struct edit_state *s = g_object_get_data (G_OBJECT (d), "edit_state");
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)))
+  {
+     if (!s->ev || !s->ev->recur || !s->ev->recur->daymask)
+     {
+        time_t t = time(NULL);
+        struct tm *lt = localtime(&t);
+          
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (s->checkbuttonwday[(lt->tm_wday+6)%7]), TRUE);
+     }
+  }
+  recalculate_sensitivities(widget, d);
+}
+
+
 static void
 unschedule_alarm (event_t ev)
 {
@@ -1061,7 +1082,7 @@ build_edit_event_window (void)
   g_signal_connect (G_OBJECT (radiobuttondaily), "toggled",
                     G_CALLBACK (recalculate_sensitivities), window);
   g_signal_connect (G_OBJECT (radiobuttonweekly), "toggled",
-                    G_CALLBACK (recalculate_sensitivities), window);
+                    G_CALLBACK (weekly_toggled), window);
   g_signal_connect (G_OBJECT (radiobuttonmonthly), "toggled",
                     G_CALLBACK (recalculate_sensitivities), window);
   g_signal_connect (G_OBJECT (radiobuttonyearly), "toggled",
@@ -1349,6 +1370,7 @@ build_edit_event_window (void)
   
   GTK_WIDGET_SET_FLAGS (summaryentry, GTK_CAN_DEFAULT);
   gtk_widget_grab_default(summaryentry);
+  g_object_set_data(G_OBJECT(window), "default-entry", summaryentry);
   
   return window;
 }
@@ -1378,7 +1400,7 @@ event_ui_init (void)
 GtkWidget *
 new_event (time_t t, guint timesel)
 {
-  GtkWidget *w = edit_event_window ();
+  GtkWidget *entry, *w = edit_event_window ();
 
   if (w)
     {
@@ -1415,7 +1437,14 @@ new_event (time_t t, guint timesel)
       gtk_option_menu_set_history (GTK_OPTION_MENU (s->optionmenutype), 0);
       s->page = 0;
       gtk_notebook_set_page (GTK_NOTEBOOK (s->notebooktype), s->page);
-    }
+	  
+      entry = g_object_get_data(G_OBJECT(w), "default-entry");
+      if (entry)
+        {
+	      gtk_widget_grab_focus(entry);
+          gtk_editable_select_region(GTK_EDITABLE(entry), 0, 0);
+        }
+	}
 
   return w;
 }
